# encoding: utf-8

require 'spec_helper'

module TTWatcher
  describe TorrentList do
    before(:each) do
      hide_const "TTWatcher::Torrent"
      fake_klass = begin class Torrent; end; Torrent end
      stub_const "TTWatcher::Torrent", fake_klass
    end

    context '#push' do
      it 'raises an exception when not allowed object going to be pushed' do
        list = described_class.new

        expect{ list.push 5 }
          .to raise_exception described_class::UnexpectedClass
      end

      it 'pushes Torrent instance to the list' do
        list = described_class.new
        fake_instance = Torrent.new

        expect(list.push(fake_instance).any?).to be true
      end
    end # context '#push'


    # ----------------------------------------------------


    context '#new' do
      it 'responds on Enumerable mixin methods' do
        list = described_class.new
        fake_instance = Torrent.new

        6.times { list << fake_instance.dup }

        expect(list.count).to eq 6
        expect(list.first).to_not be_nil
        expect(list.take 2).to be_instance_of Array
      end
    end # context '#new'
  end # describe TorrentList
end # module TTWatcher
